==> kafkaconnect-2.18.18-sources.jar: software/amazon/awssdk/services/kafkaconnect/paginators/ListCustomPluginsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.kafkaconnect.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.kafkaconnect.KafkaConnectClient;
import software.amazon.awssdk.services.kafkaconnect.model.CustomPluginSummary;
import software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsRequest;
import software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.kafkaconnect.KafkaConnectClient#listCustomPluginsPaginator(software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kafkaconnect.paginators.ListCustomPluginsIterable responses = client.listCustomPluginsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.kafkaconnect.paginators.ListCustomPluginsIterable responses = client
 *             .listCustomPluginsPaginator(request);
 *     for (software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kafkaconnect.paginators.ListCustomPluginsIterable responses = client.listCustomPluginsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of maxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listCustomPlugins(software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListCustomPluginsIterable implements SdkIterable<ListCustomPluginsResponse> {
    private final KafkaConnectClient client;

    private final ListCustomPluginsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListCustomPluginsIterable(KafkaConnectClient client, ListCustomPluginsRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListCustomPluginsResponseFetcher();
    }

    @Override
    public Iterator<ListCustomPluginsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListCustomPluginsResponse#customPlugins()} member.
     * The returned iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<CustomPluginSummary> customPlugins() {
        Function<ListCustomPluginsResponse, Iterator<CustomPluginSummary>> getIterator = response -> {
            if (response != null && response.customPlugins() != null) {
                return response.customPlugins().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListCustomPluginsResponse, CustomPluginSummary> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListCustomPluginsResponseFetcher implements SyncPageFetcher<ListCustomPluginsResponse> {
        @Override
        public boolean hasNextPage(ListCustomPluginsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListCustomPluginsResponse nextPage(ListCustomPluginsResponse previousPage) {
            if (previousPage == null) {
                return client.listCustomPlugins(firstRequest);
            }
            return client.listCustomPlugins(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> kafkaconnect-2.20.162-sources.jar: software/amazon/awssdk/services/kafkaconnect/paginators/ListCustomPluginsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.kafkaconnect.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.kafkaconnect.KafkaConnectClient;
import software.amazon.awssdk.services.kafkaconnect.internal.UserAgentUtils;
import software.amazon.awssdk.services.kafkaconnect.model.CustomPluginSummary;
import software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsRequest;
import software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.kafkaconnect.KafkaConnectClient#listCustomPluginsPaginator(software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kafkaconnect.paginators.ListCustomPluginsIterable responses = client.listCustomPluginsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.kafkaconnect.paginators.ListCustomPluginsIterable responses = client
 *             .listCustomPluginsPaginator(request);
 *     for (software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.kafkaconnect.paginators.ListCustomPluginsIterable responses = client.listCustomPluginsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of maxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listCustomPlugins(software.amazon.awssdk.services.kafkaconnect.model.ListCustomPluginsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListCustomPluginsIterable implements SdkIterable<ListCustomPluginsResponse> {
    private final KafkaConnectClient client;

    private final ListCustomPluginsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListCustomPluginsIterable(KafkaConnectClient client, ListCustomPluginsRequest firstRequest) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.nextPageFetcher = new ListCustomPluginsResponseFetcher();
    }

    @Override
    public Iterator<ListCustomPluginsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListCustomPluginsResponse#customPlugins()} member.
     * The returned iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<CustomPluginSummary> customPlugins() {
        Function<ListCustomPluginsResponse, Iterator<CustomPluginSummary>> getIterator = response -> {
            if (response != null && response.customPlugins() != null) {
                return response.customPlugins().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListCustomPluginsResponse, CustomPluginSummary> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListCustomPluginsResponseFetcher implements SyncPageFetcher<ListCustomPluginsResponse> {
        @Override
        public boolean hasNextPage(ListCustomPluginsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListCustomPluginsResponse nextPage(ListCustomPluginsResponse previousPage) {
            if (previousPage == null) {
                return client.listCustomPlugins(firstRequest);
            }
            return client.listCustomPlugins(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
